==> lambda-1.60.0-sources.jar: software/amazon/awscdk/services/lambda/LayerVersionProps.java <==
package software.amazon.awscdk.services.lambda;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:15.333Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.lambda.$Module.class, fqn = "@aws-cdk/aws-lambda.LayerVersionProps")
@software.amazon.jsii.Jsii.Proxy(LayerVersionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LayerVersionProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The content of this Layer.
     * <p>
     * Using <code>Code.fromInline</code> is not supported.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Code getCode();

    /**
     * The runtimes compatible with this Layer.
     * <p>
     * Default: - All runtimes are supported.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.lambda.Runtime> getCompatibleRuntimes() {
        return null;
    }

    /**
     * The description the this Lambda Layer.
     * <p>
     * Default: - No description.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getDescription() {
        return null;
    }

    /**
     * The name of the layer.
     * <p>
     * Default: - A name will be generated.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getLayerVersionName() {
        return null;
    }

    /**
     * The SPDX licence identifier or URL to the license file for this layer.
     * <p>
     * Default: - No license information will be recorded.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getLicense() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LayerVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LayerVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<LayerVersionProps> {
        private software.amazon.awscdk.services.lambda.Code code;
        private java.util.List<software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes;
        private java.lang.String description;
        private java.lang.String layerVersionName;
        private java.lang.String license;

        /**
         * Sets the value of {@link LayerVersionProps#getCode}
         * @param code The content of this Layer. This parameter is required.
         *             Using <code>Code.fromInline</code> is not supported.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder code(software.amazon.awscdk.services.lambda.Code code) {
            this.code = code;
            return this;
        }

        /**
         * Sets the value of {@link LayerVersionProps#getCompatibleRuntimes}
         * @param compatibleRuntimes The runtimes compatible with this Layer.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder compatibleRuntimes(java.util.List<software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes) {
            this.compatibleRuntimes = compatibleRuntimes;
            return this;
        }

        /**
         * Sets the value of {@link LayerVersionProps#getDescription}
         * @param description The description the this Lambda Layer.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of {@link LayerVersionProps#getLayerVersionName}
         * @param layerVersionName The name of the layer.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder layerVersionName(java.lang.String layerVersionName) {
            this.layerVersionName = layerVersionName;
            return this;
        }

        /**
         * Sets the value of {@link LayerVersionProps#getLicense}
         * @param license The SPDX licence identifier or URL to the license file for this layer.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder license(java.lang.String license) {
            this.license = license;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LayerVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public LayerVersionProps build() {
            return new Jsii$Proxy(code, compatibleRuntimes, description, layerVersionName, license);
        }
    }

    /**
     * An implementation for {@link LayerVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LayerVersionProps {
        private final software.amazon.awscdk.services.lambda.Code code;
        private final java.util.List<software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes;
        private final java.lang.String description;
        private final java.lang.String layerVersionName;
        private final java.lang.String license;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.code = this.jsiiGet("code", software.amazon.awscdk.services.lambda.Code.class);
            this.compatibleRuntimes = this.jsiiGet("compatibleRuntimes", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Runtime.class)));
            this.description = this.jsiiGet("description", java.lang.String.class);
            this.layerVersionName = this.jsiiGet("layerVersionName", java.lang.String.class);
            this.license = this.jsiiGet("license", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.lambda.Code code, final java.util.List<software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes, final java.lang.String description, final java.lang.String layerVersionName, final java.lang.String license) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.code = java.util.Objects.requireNonNull(code, "code is required");
            this.compatibleRuntimes = compatibleRuntimes;
            this.description = description;
            this.layerVersionName = layerVersionName;
            this.license = license;
        }

        @Override
        public software.amazon.awscdk.services.lambda.Code getCode() {
            return this.code;
        }

        @Override
        public java.util.List<software.amazon.awscdk.services.lambda.Runtime> getCompatibleRuntimes() {
            return this.compatibleRuntimes;
        }

        @Override
        public java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public java.lang.String getLayerVersionName() {
            return this.layerVersionName;
        }

        @Override
        public java.lang.String getLicense() {
            return this.license;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("code", om.valueToTree(this.getCode()));
            if (this.getCompatibleRuntimes() != null) {
                data.set("compatibleRuntimes", om.valueToTree(this.getCompatibleRuntimes()));
            }
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getLayerVersionName() != null) {
                data.set("layerVersionName", om.valueToTree(this.getLayerVersionName()));
            }
            if (this.getLicense() != null) {
                data.set("license", om.valueToTree(this.getLicense()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-lambda.LayerVersionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LayerVersionProps.Jsii$Proxy that = (LayerVersionProps.Jsii$Proxy) o;

            if (!code.equals(that.code)) return false;
            if (this.compatibleRuntimes != null ? !this.compatibleRuntimes.equals(that.compatibleRuntimes) : that.compatibleRuntimes != null) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            if (this.layerVersionName != null ? !this.layerVersionName.equals(that.layerVersionName) : that.layerVersionName != null) return false;
            return this.license != null ? this.license.equals(that.license) : that.license == null;
        }

        @Override
        public int hashCode() {
            int result = this.code.hashCode();
            result = 31 * result + (this.compatibleRuntimes != null ? this.compatibleRuntimes.hashCode() : 0);
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.layerVersionName != null ? this.layerVersionName.hashCode() : 0);
            result = 31 * result + (this.license != null ? this.license.hashCode() : 0);
            return result;
        }
    }
}

==> lambda-1.93.0-sources.jar: software/amazon/awscdk/services/lambda/LayerVersionProps.java <==
package software.amazon.awscdk.services.lambda;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:44.591Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.lambda.$Module.class, fqn = "@aws-cdk/aws-lambda.LayerVersionProps")
@software.amazon.jsii.Jsii.Proxy(LayerVersionProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface LayerVersionProps extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.services.lambda.LayerVersionOptions {

    /**
     * The content of this Layer.
     * <p>
     * Using <code>Code.fromInline</code> is not supported.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Code getCode();

    /**
     * The runtimes compatible with this Layer.
     * <p>
     * Default: - All runtimes are supported.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.util.List<software.amazon.awscdk.services.lambda.Runtime> getCompatibleRuntimes() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link LayerVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link LayerVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<LayerVersionProps> {
        private software.amazon.awscdk.services.lambda.Code code;
        private java.util.List<software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes;
        private java.lang.String description;
        private java.lang.String layerVersionName;
        private java.lang.String license;
        private software.amazon.awscdk.core.RemovalPolicy removalPolicy;

        /**
         * Sets the value of {@link LayerVersionProps#getCode}
         * @param code The content of this Layer. This parameter is required.
         *             Using <code>Code.fromInline</code> is not supported.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder code(software.amazon.awscdk.services.lambda.Code code) {
            this.code = code;
            return this;
        }

        /**
         * Sets the value of {@link LayerVersionProps#getCompatibleRuntimes}
         * @param compatibleRuntimes The runtimes compatible with this Layer.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @SuppressWarnings("unchecked")
        public Builder compatibleRuntimes(java.util.List<? extends software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes) {
            this.compatibleRuntimes = (java.util.List<software.amazon.awscdk.services.lambda.Runtime>)compatibleRuntimes;
            return this;
        }

        /**
         * Sets the value of {@link LayerVersionProps#getDescription}
         * @param description The description the this Lambda Layer.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder description(java.lang.String description) {
            this.description = description;
            return this;
        }

        /**
         * Sets the value of {@link LayerVersionProps#getLayerVersionName}
         * @param layerVersionName The name of the layer.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder layerVersionName(java.lang.String layerVersionName) {
            this.layerVersionName = layerVersionName;
            return this;
        }

        /**
         * Sets the value of {@link LayerVersionProps#getLicense}
         * @param license The SPDX licence identifier or URL to the license file for this layer.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder license(java.lang.String license) {
            this.license = license;
            return this;
        }

        /**
         * Sets the value of {@link LayerVersionProps#getRemovalPolicy}
         * @param removalPolicy Whether to retain this version of the layer when a new version is added or when the stack is deleted.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder removalPolicy(software.amazon.awscdk.core.RemovalPolicy removalPolicy) {
            this.removalPolicy = removalPolicy;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link LayerVersionProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public LayerVersionProps build() {
            return new Jsii$Proxy(code, compatibleRuntimes, description, layerVersionName, license, removalPolicy);
        }
    }

    /**
     * An implementation for {@link LayerVersionProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements LayerVersionProps {
        private final software.amazon.awscdk.services.lambda.Code code;
        private final java.util.List<software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes;
        private final java.lang.String description;
        private final java.lang.String layerVersionName;
        private final java.lang.String license;
        private final software.amazon.awscdk.core.RemovalPolicy removalPolicy;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.code = software.amazon.jsii.Kernel.get(this, "code", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Code.class));
            this.compatibleRuntimes = software.amazon.jsii.Kernel.get(this, "compatibleRuntimes", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Runtime.class)));
            this.description = software.amazon.jsii.Kernel.get(this, "description", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.layerVersionName = software.amazon.jsii.Kernel.get(this, "layerVersionName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.license = software.amazon.jsii.Kernel.get(this, "license", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.removalPolicy = software.amazon.jsii.Kernel.get(this, "removalPolicy", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.core.RemovalPolicy.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final software.amazon.awscdk.services.lambda.Code code, final java.util.List<? extends software.amazon.awscdk.services.lambda.Runtime> compatibleRuntimes, final java.lang.String description, final java.lang.String layerVersionName, final java.lang.String license, final software.amazon.awscdk.core.RemovalPolicy removalPolicy) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.code = java.util.Objects.requireNonNull(code, "code is required");
            this.compatibleRuntimes = (java.util.List<software.amazon.awscdk.services.lambda.Runtime>)compatibleRuntimes;
            this.description = description;
            this.layerVersionName = layerVersionName;
            this.license = license;
            this.removalPolicy = removalPolicy;
        }

        @Override
        public final software.amazon.awscdk.services.lambda.Code getCode() {
            return this.code;
        }

        @Override
        public final java.util.List<software.amazon.awscdk.services.lambda.Runtime> getCompatibleRuntimes() {
            return this.compatibleRuntimes;
        }

        @Override
        public final java.lang.String getDescription() {
            return this.description;
        }

        @Override
        public final java.lang.String getLayerVersionName() {
            return this.layerVersionName;
        }

        @Override
        public final java.lang.String getLicense() {
            return this.license;
        }

        @Override
        public final software.amazon.awscdk.core.RemovalPolicy getRemovalPolicy() {
            return this.removalPolicy;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("code", om.valueToTree(this.getCode()));
            if (this.getCompatibleRuntimes() != null) {
                data.set("compatibleRuntimes", om.valueToTree(this.getCompatibleRuntimes()));
            }
            if (this.getDescription() != null) {
                data.set("description", om.valueToTree(this.getDescription()));
            }
            if (this.getLayerVersionName() != null) {
                data.set("layerVersionName", om.valueToTree(this.getLayerVersionName()));
            }
            if (this.getLicense() != null) {
                data.set("license", om.valueToTree(this.getLicense()));
            }
            if (this.getRemovalPolicy() != null) {
                data.set("removalPolicy", om.valueToTree(this.getRemovalPolicy()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-lambda.LayerVersionProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            LayerVersionProps.Jsii$Proxy that = (LayerVersionProps.Jsii$Proxy) o;

            if (!code.equals(that.code)) return false;
            if (this.compatibleRuntimes != null ? !this.compatibleRuntimes.equals(that.compatibleRuntimes) : that.compatibleRuntimes != null) return false;
            if (this.description != null ? !this.description.equals(that.description) : that.description != null) return false;
            if (this.layerVersionName != null ? !this.layerVersionName.equals(that.layerVersionName) : that.layerVersionName != null) return false;
            if (this.license != null ? !this.license.equals(that.license) : that.license != null) return false;
            return this.removalPolicy != null ? this.removalPolicy.equals(that.removalPolicy) : that.removalPolicy == null;
        }

        @Override
        public final int hashCode() {
            int result = this.code.hashCode();
            result = 31 * result + (this.compatibleRuntimes != null ? this.compatibleRuntimes.hashCode() : 0);
            result = 31 * result + (this.description != null ? this.description.hashCode() : 0);
            result = 31 * result + (this.layerVersionName != null ? this.layerVersionName.hashCode() : 0);
            result = 31 * result + (this.license != null ? this.license.hashCode() : 0);
            result = 31 * result + (this.removalPolicy != null ? this.removalPolicy.hashCode() : 0);
            return result;
        }
    }
}
